#include <SoftwareSerial.h>
#include <Wire.h>                     // Use I2C library
#define ADDRESS 0x60                  // Address of CMPS10

const int pwrPin = 7;
const int gndPin = 4;
const int upBttn = 5;
const int crBttn = 6;
const int rtBttn = 8;
const int dnBttn = 9;
const int ltBttn = 10;

const int mode_set = A1;
const int mode_high = A0;
const int mode_low = A2;

const int xb_rx = 2;
const int xb_tx = 3;
SoftwareSerial Xbee(xb_rx, xb_tx);

int keyDelay = 200;
long previousMillis = 0;            // Stores last time 5-pos switch updated

void setup() {
  Serial.begin(9600);
  Xbee.begin(9600);
  Wire.begin();                    // Connect to I2C

  // Set power to 5-position switch
  pinMode(pwrPin, OUTPUT);
  digitalWrite(pwrPin, HIGH); 
  pinMode(gndPin, OUTPUT);
  digitalWrite(gndPin, LOW);
  
  // Set operating mode (switch or compass)
  pinMode(mode_high, OUTPUT);
  digitalWrite(mode_high, HIGH);
  pinMode(mode_low, OUTPUT);
  digitalWrite(mode_low, LOW);
}

void loop() {
  if (digitalRead(mode_set) == HIGH)
    buttons();
  else
    compass();
}

void buttons() {
  unsigned long currentMillis = millis();
  if(currentMillis - previousMillis > keyDelay) {
    previousMillis = currentMillis;

    if(digitalRead(ltBttn) == LOW) {
      Serial.println("left");
      Xbee.print("l");
    }
    if(digitalRead(rtBttn)== LOW) {
      Serial.println("right");
      Xbee.print("r");
    } 
    if(digitalRead(upBttn) == LOW) {
      Serial.println("up"); 
      Xbee.print("u");
    }
    if(digitalRead(dnBttn) == LOW) {
      Serial.println("down");
      Xbee.print("d");
    }
    if(digitalRead(crBttn) == LOW) {
      Serial.println("center");
      Xbee.print("c");
    }
  }
  
}

void compass(){
  byte bytehigh, bytelow;           // High and low bytes of bearing
  char pitch, roll;                 // Pitch and roll (signed values)
  int bearing;                      // Full bearing
   
  Wire.beginTransmission(ADDRESS);  // begin communication with CMPS10
  Wire.write(2);                     // Start read
  Wire.endTransmission();
  Wire.requestFrom(ADDRESS, 4);     // Request 4 bytes from CMPS10
  while(Wire.available() < 4);      // Wait for the bytes to arrive
  bytehigh = Wire.read();           // Store values
  bytelow = Wire.read();            
  pitch = Wire.read();              
  roll = Wire.read();

  Xbee.write(byte(0));
  Xbee.write(bytehigh);
  Xbee.write(bytelow);
  Xbee.write(pitch);
  Xbee.write(roll);  
   
  bearing = ((bytehigh<<8) + bytelow) / 10;  // Calculate full bearing
  print_data(bearing, pitch, roll);          // Print data
  
  delay(500);
  
}

// Print data to Serial Monitor window
void print_data(int bearing, int pitch, int roll) {
  Serial.print(bearing, DEC); 
  Serial.print(":");
  Serial.print(pitch, DEC);
  Serial.print(":");
  Serial.println(roll, DEC);
}
